%% Simple 3D plot
figure(1);clf;
hold on
legends = {};
legendIDs = [];
for i = 1:N
    pos_i = logger.get('x', coordForEach(i));
    plot3_NED(pos_i',...
        '--',col(i,:));
    plot3_NED(pos_i(:,1)',...
        'x',col(i,:));
    legendIDs(end+1) = plot3_NED(pos_i(:,end)',...
        'o',col(i,:));
    legends{end+1} = sprintf('Rover %g', i);
end
legend(legendIDs, legends)
grid on
axis([lim_x, lim_y, lim_z])
axis('equal')
view(plotView)


%% Summary plots
figure(2);clf;

% Link errors
subplot(321);
hold on
legends = {};
legendIDs = [];
if cont_pos
    for l = 1:L
        z_tilde_l = logger.get('z', coordForEach(l)) - repmat(z_d(:,l),1,length(time));
        Z_tilde_l = sqrt(sum(z_tilde_l.^2,1));
        legendIDs(end+1) = plot(time, Z_tilde_l, '--');
        legends{end+1} = sprintf('Link %g', l);
    end
    ylabel('|z_l| - |z_l^d| [m]');
else
    for l = 1:L
        z_l = logger.get('z', coordForEach(l));
        Z_l = sqrt(sum(z_l.^2,1));
        legendIDs(end+1) = plot(time, Z_l - d_l(l), '--');
        legends{end+1} = sprintf('Link %g', l);
    end
    ylabel('|z_l| - d_l [m]');
end
legend(legendIDs, legends)
title('Link length errors')
xlabel('Time [s]')
grid on

% Speed errors
subplot(323)
hold on
legends = {};
legendIDs = [];
for i = 1:N
    y_i = logger.get('v', coordForEach(i)) - logger.get('v_mission', 1:R);
    Y_i = sqrt(sum(y_i.^2,1));
    legendIDs(end+1) = plot(time, Y_i, colors{i});
    legends{end+1} = sprintf('Agent %g', i);
end
legend(legendIDs, legends)
xlabel('Time [s]')
ylabel('|y_i| [m/s]')
title('Speed errors')
grid on

% Internal feedback (tau)
tau = reshape(logger.get('tau'),R,N,[]);
for p = 1:R
    subplot(3,2,2*p)
    hold on
    for i = 1:N
        plot(time, squeeze(tau(p,i,:)), colors{i})
    end
    grid on
    xlabel('Time [s]')
    if dyn_simple
        ylabel('\tau_i [m/s]')
    else
        ylabel('\tau_i [N]')
    end
    title(['Internal feedback ' dims{p}])
end


%% External feedback (u)
figure(3);clf;

a_form = reshape(logger.get('a_form'),R,N,[]);
a_pot = reshape(logger.get('a_pot'),R,N,[]);
u = reshape(logger.get('u'),R,N,[]);

for p = 1:R
    for i = 1:N
        subplot(R,N,i+(p-1)*N)
        hold on
        plot(time, squeeze(u(p,i,:)), 'b')
        plot(time, squeeze(a_form(p,i,:)), 'r--')
        plot(time, squeeze(a_pot(p,i,:)), 'g--')
        
        grid on
        
        if p == 1
            title(sprintf('Agent %g', i))
        elseif p == R
            xlabel('Time [s]')
        end
        if i == 1
            ylabel(['External feedback ' dims{p}])
        end
    end
end









