function PlotSimulation2D(F)

textOffset = 0.2; % Text offset
col = get(groot,'DefaultAxesColorOrder');
clf

% Find first index in formation
idx_inForm = 0;
for i = 1:F.SynchedFormPos.N
    if F.SynchedFormPos.inFormation(i)
        idx_inForm = i;
        break;
    end
end



%% Plot 2D pos (North & East coordinates)
hold on
legends = {};
legendIDs = [];
for i = 1:F.N
    % Position
    plot(F.SynchedFormPos.y{i},F.SynchedFormPos.x{i},...
        '--','Color',col(i,:));
    % In formation
    plot(F.SynchedFormPos.y{i}(F.SynchedFormPos.inFormation),...
        F.SynchedFormPos.x{i}(F.SynchedFormPos.inFormation),...
        '.','Color',col(i,:));
    % Starting position
    plot(F.SynchedFormPos.y{i}(1),F.SynchedFormPos.x{i}(1),...
        'x','Color',col(i,:));
    % Final position
    legendIDs(end+1) = plot(F.SynchedFormPos.y{i}(end),F.SynchedFormPos.x{i}(end),...
        'o','Color',col(i,:));
    legends{end+1} = sprintf('Agent %g', i);
end

%% Plot desired horizontal formation
if idx_inForm
    linkLegendAdded = false;
    for link = 1:F.L
        i_neg = 0;
        i_pos = 0;
        for agent = 1:numel(F.D(:,link))
            if F.D(agent,link) == -1
                i_neg = agent;
            elseif F.D(agent,link) == 1
                i_pos = agent;
            end
        end
        Xneg = F.SynchedFormPos.x{i_neg}(idx_inForm);
        Yneg = F.SynchedFormPos.y{i_neg}(idx_inForm);
        Xpos = F.SynchedFormPos.x{i_pos}(idx_inForm);
        Ypos = F.SynchedFormPos.y{i_pos}(idx_inForm);
        
        plot([Yneg,Ypos],[Xneg,Xpos],...
            '-.k');
        if ~linkLegendAdded
            legendIDs(end+1) = plot(Yneg,Xneg,...
                'sk');
            legends{end+1} = sprintf('Formation');
            linkLegendAdded = true;
        end
        plot(Ypos,Xpos,...
            'sk');
        
        % Plot value of desired formation
        dir = 1;
        if Xneg < Xpos && Yneg < Ypos || Xneg > Xpos && Yneg > Ypos
            dir = -1;
        end
        text(mean([Yneg,Ypos]),mean([Xneg,Xpos])+textOffset*dir,...
            sprintf('z_%d = [%.1f, %.1f, %.1f]^T',...
            link, F.Z(1,link), F.Z(2,link), F.Z(3,link)));
    end
end

hold off
grid on
xlabel('East [m]');
ylabel('North [m]');
%title('Position');
%axis equal

% Add legends
h = legend(legendIDs, legends);
h.Location = 'southwest';



% Add title
if isfield(F,'name')
    suptitle(F.name)
end

end