function PlotSimulation3D(F)

textOffset = 0.3; % Text offset
marg = 0.25; % Axis margin
col = get(groot,'DefaultAxesColorOrder');
clf

plotDesired = false;

% Find first index in formation
idx_inForm = 0;
for i = 1:F.SynchedFormPos.N
    if F.SynchedFormPos.inFormation(i)
        idx_inForm = i;
        break;
    end
end



%% Plot 3D pos (North, East, Down coordinates)
hold on
legends = {};
legendIDs = [];
max_pos = [F.SynchedFormPos.x{1}(1),F.SynchedFormPos.y{1}(1),F.SynchedFormPos.z{1}(1)];
min_pos = max_pos;
for i = 1:F.N
    pos_i = [F.SynchedFormPos.x{i}, F.SynchedFormPos.y{i}, F.SynchedFormPos.z{i}];
    % Position
    plot3_NED(pos_i,...
        '--',col(i,:));
    % In formation
    plot3_NED(pos_i(F.SynchedFormPos.inFormation,:),...
        '.',col(i,:));
    % Starting position
    plot3_NED(pos_i(1,:),...
        'x',col(i,:));
    % Final position
    legendIDs(end+1) = plot3_NED(pos_i(end,:),...
        'o',col(i,:));
    legends{end+1} = sprintf('Agent %g', i);
    
    max_pos = max([max_pos;pos_i]);
    min_pos = min([min_pos;pos_i]);
end

%% Plot desired formation
if idx_inForm && plotDesired
    linkLegendAdded = false;
    for link = 1:F.L
        i_neg = 0;
        i_pos = 0;
        for agent = 1:numel(F.D(:,link))
            if F.D(agent,link) == -1
                i_neg = agent;
            elseif F.D(agent,link) == 1
                i_pos = agent;
            end
        end
        Xneg = F.SynchedFormPos.x{i_neg}(idx_inForm);
        Yneg = F.SynchedFormPos.y{i_neg}(idx_inForm);
        Zneg = F.SynchedFormPos.z{i_neg}(idx_inForm);
        Xpos = F.SynchedFormPos.x{i_pos}(idx_inForm);
        Ypos = F.SynchedFormPos.y{i_pos}(idx_inForm);
        Zpos = F.SynchedFormPos.z{i_pos}(idx_inForm);
        links = [Xneg,Yneg,Zneg; Xpos,Ypos,Zpos];
        
        if ~linkLegendAdded
            legendIDs(end+1) = plot3_NED(links,...
                '-.k');
            legends{end+1} = sprintf('Desired formation');
            linkLegendAdded = true;
        else
            plot3_NED(links,...
                '-.k');
        end
        plot3_NED(links,...
            'sk');
        
%         % Plot value of desired formation
%         dir = 1;
%         if Xneg < Xpos && Yneg < Ypos || Xneg > Xpos && Yneg > Ypos
%             dir = -1;
%         end
%         text(mean([Xneg,Xpos])+textOffset*dir,mean([Yneg,Ypos])+textOffset,mean([Zneg,Zpos]),...
%             sprintf('z_%d = [%.1f, %.1f, %.1f]^T',...
%             link, F.Z(1,link), F.Z(2,link), F.Z(3,link)));
    end
end

hold off
grid on

% Add legends
h = legend(legendIDs, legends);
h.Location = 'northeast';

lim_x = [min_pos(1)-marg, max_pos(1)+marg];
lim_y = [min_pos(2)-marg, max_pos(2)+marg];
lim_z = [min_pos(3)-marg, max_pos(3)+marg];


axis('equal')
view(F.plotView)
axis([lim_x, lim_y, lim_z])


% Add title
if isfield(F,'name')
    suptitle(F.name)
end

end

