classdef Plotter < handle
    %PLOTTER Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        handles = [];
        plots = repmat(struct('name', '', 'subcell', {}), 0, 1);
        Size  = [2 3];
        fig   = 0;
    end
    
    methods
        function this = Plotter(fig)
            this = this@handle;
            this.handles = [];
            
            if nargin < 1
                fig = gcf;
            end
            
            this.fig = fig;
            
        end
        
        function a = plot(this, varargin)
            if isempty(this.handles)
                this.handles = plot(varargin{:});
            else
                this.handles = [this.handles plot(varargin{:})];
            end
            
            a = this.handles(end);
            
        end
        
        function setSize(obj, rows, cols)
            obj.Size = [rows cols];
        end
        
        function activate(obj, name, spot)
            
           plotObj = struct('name', name, 'subcell', {{1,1,[]}});
            
           
           if strcmp('main', name)
               % always use nRows*2
               
               % Generate selection array
               sel = [];
               for row = 1:obj.Size(1)
                   start = ( (row-1) * obj.Size(2) )+1;
                   sel = [sel  start:start+1];
               end
               
               plotObj.subcell = {{obj.Size(1), obj.Size(2), sel}};
           else
              if nargin < 3
                  spot = 0;
                  %error('Must supply spot');
                  
                  % Finding next available spot!
                  
                  for i = 1:obj.Size(1)*obj.Size(2)
                     found = 0;
                     for j = 1:length(obj.plots)
                         spots = obj.plots(j).subcell{1}(3);
                         if find([spots{:}] == i)
                             found = 1;
                         end
                     end
                     if ~found
                         spot = i;
                         break;
                     end
                  end
                  
              end
              if spot == 0
                 %warning('No more spots left!'); 
                 return;
              end
              plotObj.subcell = {{obj.Size(1), obj.Size(2), spot}};
           end
           
           obj.plots(end+1) = plotObj;
        end
        
        function [on, subcell] = isActive(obj, name)
            on = 0; subcell = {0,0,0};
            i = find(strcmp(name, {obj.plots.name}));
            if i
                on = 1;
                subcell = obj.plots(i).subcell;
            end
                
        end
        
        function [handle] = line(this, varargin)
            handle = line(varargin{:});
            if isempty(this.handles)
                this.handles = handle;
            else
                this.handles = [this.handles handle];
            end
        end
        
        function this = deleteOld(this)

            if ~isempty(this.handles)
                
                delete(this.handles(ishghandle(this.handles)));
                this.handles = [];
            end

            %if all(ishandle(this.handles))
             %   delete(this.handles);
             %   this.handles = [];
            %end
        end
    end
    
end

