function newF = ExtractFormationData(F)
%UNTITLED6 Summary of this function goes here
%   Detailed explanation goes here
conversion;

F.N = numel(F.agents);
F.L = size(F.D,2);
if ~isfield(F,'WPtracking')
    F.WPtracking = false;
end
if ~isfield(F,'ESTATEoffset')
    F.ESTATEoffset = false;
end
WPfound = false;


for i = 1:F.N
    F.log{i} = load(fullfile(F.path,F.agents{i}));
    if isfield(F.log{i},'FormPos')
        F.FormPos{i} = FilterLocalMsg(F.log{i},'FormPos');
    end
    
    % Check if reference LLH has changed in dataset
    lat_diff = max(F.log{i}.EstimatedState.lat)-min(F.log{i}.EstimatedState.lat);
    if lat_diff > 1e-12 % Because of floating point precision
        display('ERR: Ref LLH has changed during dataset for ',F.agents{i},'!');
        return
    end
    
    % Check occurrence of RtkFix
    if F.ReportRTK && isfield(F,'name')
        Rtk.none = 0;
        Rtk.obs = 0;
        Rtk.float = 0;
        Rtk.fix = 0;
        for n = 1:numel(F.log{i}.RtkFix.timestamp)
            if strfind(F.log{i}.RtkFix.type(n,:),'FIXED')
                Rtk.fix = Rtk.fix + 1;
            elseif strfind(F.log{i}.RtkFix.type(n,:),'FLOAT')
                Rtk.float = Rtk.float + 1;
            elseif strfind(F.log{i}.RtkFix.type(n,:),'OBS')
                Rtk.obs = Rtk.obs + 1;
            else
                Rtk.none = Rtk.none +1;
            end
        end
        display(sprintf('%s\n None: %d\n Obs: %d\n Float: %d\n Fix: %d', ...
            F.name, Rtk.none, Rtk.obs, Rtk.float, Rtk.fix));
    end
    
    if F.ESTATEoffset
        % Synchronize FormPos (RTK) with ESTATE
        tsForm = timeseries([F.FormPos{i}.x,F.FormPos{i}.y,F.FormPos{i}.z],F.FormPos{i}.ots);
        tsEstate = timeseries([F.log{i}.EstimatedState.x,F.log{i}.EstimatedState.y,F.log{i}.EstimatedState.z],F.log{i}.EstimatedState.timestamp);
        [tsForm,tsEstate] = synchronize(tsForm,tsEstate,'Union');
        % Get offset from first synchronized positions
        F.offset{i} = (tsEstate.Data(1,:) - tsForm.Data(1,:))';
        % Subtract offset in ESTATE
        F.log{i}.EstimatedState.x = F.log{i}.EstimatedState.x - F.offset{i}(1);
        F.log{i}.EstimatedState.y = F.log{i}.EstimatedState.y - F.offset{i}(2);
        F.log{i}.EstimatedState.z = F.log{i}.EstimatedState.z - F.offset{i}(3);
    end
    
    % Search for WPs in DesiredPath if not found yet
    if ~WPfound && F.log{i}.DesiredPath.end_lat(1) ~= 0 && F.log{i}.DesiredPath.end_lon(1) ~= 0
        WPfound = true;
        F.leaderID = i;
        F.WP.ned = lla2flat([F.log{i}.DesiredPath.end_lat*R2D,F.log{i}.DesiredPath.end_lon*R2D,F.log{i}.DesiredPath.end_z],...
        [F.log{i}.EstimatedState.lat(1)*R2D,F.log{i}.EstimatedState.lon(1)*R2D],0,F.log{i}.EstimatedState.height(1));
        F.WP.ned = F.WP.ned.';
        F.WP.N = size(F.WP.ned,2);
        F.WP.t = F.log{i}.DesiredPath.timestamp;
                
        if F.ESTATEoffset
            % Subtract offset in WPs
            F.WP.ned = F.WP.ned - repmat(F.offset{i},1,F.WP.N);
        end
    end
end


%% Extraction only when multiple agents

if F.N < 2
    newF = F;
    return
end

if isfield(F,'plotGuidedOnly') && F.plotGuidedOnly
    % Cut postition data if mode GUIDED ends early
    for i = 1:F.N
        for j = numel(F.log{i}.AutopilotMode.timestamp):-1:1
            if strfind(F.log{i}.AutopilotMode.mode(j,:),'GUIDED')
                guidedEnd = F.log{i}.AutopilotMode.timestamp(j);
                if guidedEnd < F.log{i}.AutopilotMode.timestamp(end)
                    idx = F.FormPos{i}.ots <= guidedEnd;
                    F.FormPos{i} = structfun(@(x) x(idx), F.FormPos{i}, 'UniformOutput', false);
                    idx = F.log{i}.EstimatedState.timestamp <= guidedEnd;
                    F.log{i}.EstimatedState = structfun(@(x) x(idx), F.log{i}.EstimatedState, 'UniformOutput', false);
                end
                break;
            end
        end            
    end
end

% Use timeseries to synchronize position and velocity data in new struct
timeName = 'ots'; % Time to use for synchronization
dataNames = {'x','y','z','vx','vy','vz'}; % Datafields to keep (and interpolate)
for i = 1:F.N
    timeArray = F.FormPos{i}.(timeName);
    dataArray = NaN(numel(timeArray),numel(dataNames));
    for j = 1:numel(dataNames)
        dataArray(:,j) = F.FormPos{i}.(dataNames{j});
    end
    ts{i} = timeseries(dataArray,timeArray);
end

% Synchronize all permutations of pairs
for ii = 1:F.N
    for jj = 1:F.N
        if ii ~= jj
            % Chose Union to keep all times, Uniform to sample at given
            % interval
            %[ts{ii},ts{jj}] = synchronize(ts{ii},ts{jj},'Union');
            [ts{ii},ts{jj}] = synchronize(ts{ii},ts{jj},'Uniform','Interval',0.05);
        end
    end
end

% Rebuild synchronized datastruct
F.SynchedFormPos.t = ts{1}.Time;
F.SynchedFormPos.N = numel(F.SynchedFormPos.t);
for i = 1:F.N
    for j = 1:numel(dataNames)
        F.SynchedFormPos.(dataNames{j}){i} = ts{i}.Data(:,j);
    end
end

% Get desired formation
if ~isfield(F,'X')
    % Assume hold current formation
    F.X = NaN(3,F.N);
    for ii = 1:F.N
        F.X(:,ii) = [F.SynchedFormPos.x{ii}(1);
                     F.SynchedFormPos.y{ii}(1);
                     F.SynchedFormPos.z{ii}(1)];
    end
end

% Calculate desired difference variables
z_d = kron(F.D',eye(3))*reshape(F.X,[],1);
F.Z = reshape(z_d,3,[]);

% Extract X, Z, Z_tilde and check when formation is within threshold
F.SynchedFormPos.inFormation = ones(F.SynchedFormPos.N,1);
F.SynchedFormPos.X = NaN(3,F.N,F.SynchedFormPos.N);
F.SynchedFormPos.Z = NaN(3,F.L,F.SynchedFormPos.N);
F.SynchedFormPos.Z_tilde = F.SynchedFormPos.Z;
if isfield(F,'error2D') && F.error2D
    F.errDims = 1:2;
else
    F.errDims = 1:3;
end
for ii = 1:F.SynchedFormPos.N
    for rover = 1:F.N
        F.SynchedFormPos.X(:,rover,ii) = [F.SynchedFormPos.x{rover}(ii);
                                          F.SynchedFormPos.y{rover}(ii);
                                          F.SynchedFormPos.z{rover}(ii)];
    end
    z = kron(F.D',eye(3))*reshape(F.SynchedFormPos.X(:,:,ii),[],1);
    F.SynchedFormPos.Z(:,:,ii) = reshape(z,3,[]);
    F.SynchedFormPos.Z_tilde(:,:,ii) = F.SynchedFormPos.Z(:,:,ii) - F.Z;
    for link = 1:F.L
        if norm(F.SynchedFormPos.Z_tilde(F.errDims,link,ii)) > F.formationThreshold
            F.SynchedFormPos.inFormation(ii) = 0;
            break;
        end
    end    
end
F.SynchedFormPos.inFormation = logical(F.SynchedFormPos.inFormation);

newF = F;
end

