function PlotFormationAltitude(F)

clf
col = get(groot,'DefaultAxesColorOrder');
if ~isfield(F,'plotESTATE')
    F.plotESTATE = false;
end

% Find first index in formation
idx_inForm = 0;
for i = 1:F.SynchedFormPos.N
    if F.SynchedFormPos.inFormation(i)
        idx_inForm = i;
        break;
    end
end

%% Plot altitudes (Down coordinates)

t_0 = F.SynchedFormPos.t(1);
time = F.SynchedFormPos.t - t_0;

hold on
for i = 1:F.N
    % Altitude
    plot(time, F.SynchedFormPos.z{i},...
        '--','Color',col(i,:));
    % In formation
    plot(time(F.SynchedFormPos.inFormation),...
        F.SynchedFormPos.z{i}(F.SynchedFormPos.inFormation),...
        '.','Color',col(i,:));
    % Plot ESTATE
    if F.plotESTATE
        plot(F.log{i}.EstimatedState.timestamp-t_0,F.log{i}.EstimatedState.z,...
            '-.','Color',col(5,:));
    end
end

% % Plot desired vertical formation
% if idx_inForm
%     for link = 1:F.L
%         i_neg = 0;
%         i_pos = 0;
%         for agent = 1:numel(F.D(:,link))
%             if F.D(agent,link) == -1
%                 i_neg = agent;
%             elseif F.D(agent,link) == 1
%                 i_pos = agent;
%             end
%         end
%         Zneg = F.SynchedFormPos.z{i_neg}(idx_inForm);
%         Zpos = F.SynchedFormPos.z{i_pos}(idx_inForm);
%         
%         
%         plot([time(idx_inForm),time(idx_inForm)],[Zneg,Zpos],...
%             '-.k');         
%         plot(time(idx_inForm),Zneg,...
%             'sk');
%         plot(time(idx_inForm),Zpos,...
%             'sk');
%         
%         % Plot value of desired formation
%         text(time(idx_inForm)+textOffset,mean([Zneg,Zpos]),...
%             sprintf('z_%d = [%.1f, %.1f, %.1f]^T',...
%             link, F.Z(1,link), F.Z(2,link), F.Z(3,link)));
%     end
% end

%% Plot waypoint heights
if F.WPtracking && F.plotWPaltitude
    for i = 1:F.WP.N
        % Only plot if not looped WP
        if i == 1 || F.WP.ned(1,i) ~= F.WP.ned(1,1) || F.WP.ned(2,i) ~= F.WP.ned(2,1)
            plot([time(1),time(end)],[F.WP.ned(3,i),F.WP.ned(3,i)],...
                ':','Color',col(i+F.N,:));
            if F.WP.N > 1 && i < F.WP.N
                plot(F.WP.t(i+1)-t_0,F.WP.ned(3,i), ...
                    'p','Color',col(i+F.N,:));
            else
                plot(time(end),F.WP.ned(3,i), ...
                    'p','Color',col(i+F.N,:));
            end
        end
    end
end

hold off
grid on
xlabel('Time [s]');
ylabel('Down [s]');
set(gca,'ydir','reverse')
%title('Altitude');
axis tight
xlim([0,F.SynchedFormPos.t(end) - t_0]);


% Add title
if isfield(F,'name')
    suptitle(F.name)
end
end

