function [ exportPath ] = exportPlot( figureNumber, fileName, size, aspectRatio )
%EXPORTPLOT exporterer med den nye exportFig
    
    % First, check if figureNumber is a handle
    if any(ishandle(figureNumber))
        fig = figureNumber;
    else
        fig = figure(figureNumber);
    end

    % Get the full path
    exportPath = fullfile(getTexPath(), 'plots', fileName);
    
    % Default width
    fullsizeWidth = 12.1236;
    defaultAspectRatio = 1;
    
    % Check for aspect ratio argument
    if nargin <= 3
        aspectRatio = defaultAspectRatio;
    end    
    % Check for the size argument
    if nargin <= 2
        size = 'full';
    end
    
    if isnumeric(size)
        width = size*fullsizeWidth;
    else
        switch size
            case 'full'
                width = fullsizeWidth;
            case 'half'
                width = fullsizeWidth/2;
            case 'double'
                width = fullsizeWidth*2;
        end
    end
    
    if isnumeric(aspectRatio)
        if aspectRatio < 0
            aspectRatio = defaultAspectRatio;
        end
        height = width/aspectRatio;
    else
        switch aspectRatio
            case 'golden'
                height = width/1.6180;
            otherwise
                height = width;
        end
    end
   
    
    exportfig(fig, exportPath, 'fontmode', 'fixed', ...
                                'fontsize', '8', ...
                                'height', height, ...
                                'width', width,...
                                'LineMode', 'fixed', 'LineWidth', 0.7);
    
    
end